Revert SEED handling and comment orocessing. It broke database compilation.
[open-adventure.git] / misc.c
diff --git a/misc.c b/misc.c
index f1bd954c7932cdf9c463c072c2f1a970b166e340..b87c76913f6aab68b500979b20adce84fb05d443 100644 (file)
--- a/misc.c
+++ b/misc.c
@@ -723,7 +723,7 @@ L2: ATDWRF=I;
 
 
 
/*  Utility routines (SETBIT, TSTBIT, set_seed, get_next_lcg_value, randrange, RNDVOC, BUG) */
 
 #undef SETBIT
 long fSETBIT(long BIT) {
@@ -758,10 +758,11 @@ long TSTBIT;
 
 #define TSTBIT(MASK,BIT) fTSTBIT(MASK,BIT)
 
-void set_seed(long seedval)
+void set_seed_from_time(void)
 {
-       srand(seedval);
-       lcgstate.x = (unsigned long) rand() % lcgstate.m;
+  /* Use the current system time to get seed the ISO rand() function, from which we get a seed for the LCG. */
+  srand(time(NULL));
+  lcgstate.x = (unsigned long) rand() % lcgstate.m;
 }
 
 unsigned long get_next_lcg_value(void)
@@ -854,8 +855,8 @@ void fBUG(long NUM) {
 #define BUG(NUM) fBUG(NUM)
 #undef MAPLIN
 void fMAPLIN(FILE *OPENED) {
-       signed char *cp;
-    
+long I, VAL;
+
 /*  Read a line of input, from the specified input source,
  *  translate the chars to integers in the range 0-126 and store
  *  them in the common array "INLINE".  Integer values are as follows:
@@ -885,18 +886,21 @@ void fMAPLIN(FILE *OPENED) {
 
        if (!oldstyle && SETUP)
            fputs("> ", stdout);
-       IGNORE(fgets(raw_input,sizeof(INLINE)-1,OPENED));
+       IGNORE(fgets(INLINE+1,sizeof(INLINE)-1,OPENED));
        if (feof(OPENED)) {
                if (logfp)
                        fclose(logfp);
        } else {
                if (logfp)
-                       IGNORE(fputs(raw_input, logfp));
+                       IGNORE(fputs(INLINE+1, logfp));
                else if (!isatty(0))
-                       IGNORE(fputs(raw_input, stdout));
-               for (cp = raw_input; *cp; cp++)
-                       INLINE[cp - raw_input + 1]=MAP1[*cp + 1];
-               LNLENG = (cp - raw_input);
+                       IGNORE(fputs(INLINE+1, stdout));
+               LNLENG=0;
+               for (I=1; I<=sizeof(INLINE) && INLINE[I]!=0; I++) {
+               VAL=INLINE[I]+1;
+               INLINE[I]=MAP1[VAL];
+               if(INLINE[I] != 0)LNLENG=I;
+               } /* end loop */
                LNPOSN=1;
        }
 }
@@ -723,7 +723,7 @@ L2: ATDWRF=I;
 
 
-/*  Utility routines (SETBIT, TSTBIT, set_seed, get_next_lcg_value, randrange, RNDVOC, BUG) */
+/*  Utility routines (SETBIT, TSTBIT, set_seed_from_time, get_next_lcg_value, randrange, RNDVOC, BUG) */
 
 #undef SETBIT